@@ -74,7 +74,7 @@
 #' progressively add 1 split at a time and calculate selected metric. For running window,
 #' select the length of running window with the k_running_window argument.
 #' @param k_running_window the length of running window for temporal stability check.
-#' Applicalbe only if temporal_stability argument is set to running window.
+#' Applicable only if temporal_stability argument is set to running window.
 #' @param k integer, number of breaks (splits) for temporal stability and cross validation
 #' analysis.
 #' @param cross_validation_type character string, specifying, how to perform cross validation
@@ -104,8 +104,18 @@
 #' The optimal selection, which describes the optimal consecutive days that returns
 #' the highest calculated metric and is obtained by the $plot_extreme output, is the
 #' same for all three reference windows.
+#' @param boot logical, if TRUE, bootstrap procedure will be used to calculate
+#' estimates correlation coefficients, R squared or adjusted R squared metrices
+#' @param boot_n The number of bootstrap replicates
+#' @param boot_ci_type A character string representing the type of bootstrap intervals
+#' required. The value should be any subset of the values c("norm","basic", "stud",
+#' "perc", "bca").
+#' @param boot_conf_int A scalar or vector containing the confidence level(s) of
+#' the required interval(s)
 #'
-#' @return a list with 15 elements:
+#'
+#'
+#' @return a list with 17 elements:
 #' \tabular{rll}{
 #'  1 \tab $calculations   \tab a matrix with calculated metrics\cr
 #'  2 \tab $method \tab the character string of a method \cr
@@ -121,7 +131,9 @@
 #'  12 \tab $plot_specific    \tab ggplot2 object: line plot of a row with a selected window width in a matrix of calculated metrics\cr
 #'  13 \tab $PCA_output    \tab princomp object: the result output of the PCA analysis\cr
 #'  14 \tab $type    \tab the character string describing type of analysis: daily or monthly\cr
-#'  15 \tab $reference_window \tab character string, which referece window was used for calculations
+#'  15 \tab $reference_window \tab character string, which reference window was used for calculations\cr
+#'  16 \tab $boot_lower \tab matrix with lower limit of confidence intervals of bootstrap calculations\cr
+#'  17 \tab $boot_upper \tab matrix with upper limit of confidence intervals of bootstrap calculations
 #'}
 #'
 #' @export
@@ -141,16 +153,19 @@
 #'
 #' # 1 Example with fixed width
 #' example_daily_response <- daily_response(response = data_MVA, env_data = LJ_daily_temperatures,
-#'                                      method = "cor", fixed_width = 0,
-#'                                      row_names_subset = TRUE, remove_insignificant = TRUE,
+#'                                      method = "lm", fixed_width = 0, lower_limit = 30,
+#'                                      upper_limit = 60, row_names_subset = TRUE,
+#'                                      remove_insignificant = TRUE,
 #'                                      alpha = 0.05, aggregate_function = 'mean',
-#'                                      reference_window = "end", previous_year = TRUE,
-#'                                      cor_method = "spearman")
+#'                                      reference_window = "end", previous_year = FALSE,
+#'                                      cor_method = "spearman", boot = FALSE,
+#'                                      boot_n = 100)
 #' class(example_daily_response)
 #' summary(example_daily_response)
 #' example_daily_response$plot_extreme
 #' example_daily_response$plot_heatmap
 #'
+#'
 #' # 2 Example for past and present
 #' example_MVA_past <- daily_response(response = data_MVA, env_data = LJ_daily_temperatures,
 #' method = "cor", lower_limit = 21, upper_limit = 180,
@@ -228,7 +243,8 @@ daily_response <- function(response, env_data, method = "lm",
                            k_running_window = 30, cross_validation_type = "blocked",
                            subset_years = NULL, plot_specific_window = NULL,
                            ylimits = NULL, seed = NULL, tidy_env_data = FALSE,
-                           reference_window = 'start') {
+                           reference_window = 'start',  boot = FALSE, boot_n = 1000,
+                           boot_ci_type = "norm", boot_conf_int = 0.95) {
 
 
   if (!is.null(seed)) {
@@ -251,6 +267,20 @@ daily_response <- function(response, env_data, method = "lm",
  DE <- NULL
  d <- NULL
 
+
+
+   temporal_matrix_lower <- NULL
+   temporal_matrix_upper <- NULL
+
+
+   if (boot == TRUE & method != "cor"){
+
+     warning(paste0("Bootstrapping is currently available only for correlation coefficients!",
+             "boot argument is ignored!"))
+
+   }
+
+
  # If there is a column name samp.depth in response data frame, warning is given
  if ("samp.depth" %in% colnames(response)){
 
@@ -364,7 +394,7 @@ daily_response <- function(response, env_data, method = "lm",
   # If row_names_subset == TRUE, data is subseted and ordered based on matching
   # row.names. Additionally, number of characters in row.names is checked.
   # There should be at least three characters (assuming years before 100 will
-  # never be analysed, there is no such environmental data avaliable)
+  # never be analysed, there is no such environmental data available)
   if (row_names_subset == TRUE & nchar(row.names(env_data)[1]) >= 3){
 
     ncol_response <- ncol(response)
@@ -495,6 +525,11 @@ daily_response <- function(response, env_data, method = "lm",
                                                    1 + fixed_width/2 ),0))
       }
 
+    # Here I create two additional temporal matrices, which will be used to store
+    # lower and upper limits of bootstrap estimates
+    temporal_matrix_lower <- temporal_matrix
+    temporal_matrix_upper <- temporal_matrix
+
       pb <- txtProgressBar(min = 0, max = (ncol(env_data) - fixed_width),
                            style = 3)
 
@@ -566,6 +601,11 @@ daily_response <- function(response, env_data, method = "lm",
                                                  1 + fixed_width/2 ),0))
     }
 
+    # Here I create two additional temporal matrices, which will be used to store
+    # lower and upper limits of bootstrap estimates
+    temporal_matrix_lower <- temporal_matrix
+    temporal_matrix_upper <- temporal_matrix
+
     pb <- txtProgressBar(min = 0, max = (ncol(env_data) - fixed_width),
                          style = 3)
 
@@ -640,6 +680,11 @@ daily_response <- function(response, env_data, method = "lm",
                                                  1 + fixed_width/2 ),0))
     }
 
+    # Here I create two additional temporal matrices, which will be used to store
+    # lower and upper limits of bootstrap estimates
+    temporal_matrix_lower <- temporal_matrix
+    temporal_matrix_upper <- temporal_matrix
+
     pb <- txtProgressBar(min = 0, max = (ncol(env_data) - fixed_width),
                          style = 3)
 
@@ -741,6 +786,11 @@ daily_response <- function(response, env_data, method = "lm",
                                                  1 + lower_limit/2 ),0))
     }
 
+    # Here I create two additional temporal matrices, which will be used to store
+    # lower and upper limits of bootstrap estimates
+    temporal_matrix_lower <- temporal_matrix
+    temporal_matrix_upper <- temporal_matrix
+
   # An iterating double loop: 1 outer loop) iterating from lower_limit :
   # upper_limit defines windo.width used for a moving window. 2) inner loop
   # defines the starting position of a moving window.
@@ -773,15 +823,38 @@ daily_response <- function(response, env_data, method = "lm",
         stop(paste0("aggregate function is ", aggregate_function, ". Instead it should be mean, median or sum."))
       }
 
+
       x <- matrix(x, nrow = nrow(env_data), ncol = 1)
-      temporal_correlation <- cor(response[, 1], x[, 1])
+
+       if (boot == FALSE){
+          temporal_correlation <- cor(response[, 1], x[, 1], method = cor_method)
+          temporal_lower <- NA
+          temporal_upper <- NA
+      } else if (boot == TRUE){
+      temp_df_boot <- cbind(response[, 1], x[, 1])
+      calc <- boot(temp_df_boot, boot_f, fun = "cor", cor.type = cor_method, R = boot_n)
+
+      temporal_correlation <- colMeans(calc$t)[1]
+
+      ci_int <- boot.ci(calc, conf = boot_conf_int, type = boot_ci_type)
+      temporal_lower <- ci_int$norm[2]
+      temporal_upper <- ci_int$norm[3]
+      } else {
+      print(paste0("boot should be TRUE or FALSE, instead it is ", boot))
+    }
 
       if (reference_window == 'start'){
         temporal_matrix[(K - lower_limit) + 1, j + 1] <- temporal_correlation
+        temporal_matrix_lower[(K - lower_limit) + 1, j + 1] <- temporal_lower
+        temporal_matrix_upper[(K - lower_limit) + 1, j + 1] <- temporal_upper
       } else if (reference_window == 'end'){
         temporal_matrix[(K - lower_limit) + 1, j + K] <- temporal_correlation
+        temporal_matrix_lower[(K - lower_limit) + 1, j + K] <- temporal_lower
+        temporal_matrix_upper[(K - lower_limit) + 1, j + K] <- temporal_upper
       } else if (reference_window == 'middle'){
         temporal_matrix[(K - lower_limit) + 1, round2(j + 1 + K/2, 0)] <- temporal_correlation
+        temporal_matrix_lower[(K - lower_limit) + 1, round2(j + 1 + K/2, 0)] <- temporal_lower
+        temporal_matrix_upper[(K - lower_limit) + 1, round2(j + 1 + K/2, 0)] <- temporal_upper
       }
 
 
@@ -797,10 +870,15 @@ daily_response <- function(response, env_data, method = "lm",
   temporal_rownames <- as.vector(seq(from = lower_limit, to = upper_limit,
     by = 1))
   row.names(temporal_matrix) <- temporal_rownames
+  row.names(temporal_matrix_lower) <- temporal_rownames
+  row.names(temporal_matrix_upper) <- temporal_rownames
+
 
   temporal_colnames <- as.vector(seq(from = 1,
     to = ncol(temporal_matrix), by = 1))
   colnames(temporal_matrix) <- temporal_colnames
+  colnames(temporal_matrix_lower) <- temporal_colnames
+  colnames(temporal_matrix_upper) <- temporal_colnames
   }
 
   # B.2 method == "lm"
@@ -819,6 +897,10 @@ daily_response <- function(response, env_data, method = "lm",
                                                  1 + lower_limit/2 ),0))
     }
 
+    # Here I create two additional temporal matrices, which will be used to store
+    # lower and upper limits of bootstrap estimates
+    temporal_matrix_lower <- temporal_matrix
+    temporal_matrix_upper <- temporal_matrix
 
     pb <- txtProgressBar(min = 0, max = (upper_limit - lower_limit),
                          style = 3)
@@ -840,12 +922,15 @@ daily_response <- function(response, env_data, method = "lm",
           stop(paste0("aggregate function is ", aggregate_function, ". Instead it should be mean, median or sum."))
         }
 
-        x <- matrix(x, nrow = nrow(env_data), ncol = 1)
-        temporal_df <- data.frame(cbind(x, response))
-        temporal_model <- lm(x ~ ., data = temporal_df)
-        temporal_summary <- summary(temporal_model)
-        temporal_r_squared <- temporal_summary$r.squared
-        temporal_adj_r_squared <- temporal_summary$adj.r.squared
+          x <- matrix(x, nrow = nrow(env_data), ncol = 1)
+          temporal_df <- data.frame(cbind(x, response))
+          temporal_model <- lm(x ~ ., data = temporal_df)
+          temporal_summary <- summary(temporal_model)
+          temporal_r_squared <- temporal_summary$r.squared
+          temporal_adj_r_squared <- temporal_summary$adj.r.squared
+
+          temporal_lower <- NA
+          temporal_upper <- NA
 
         if (metric == "r.squared"){
 
@@ -899,7 +984,10 @@ daily_response <- function(response, env_data, method = "lm",
                                 ncol = round2((ncol(env_data) - lower_limit +
                                                  1 + lower_limit/2 ),0))
     }
-
+    # Here I create two additional temporal matrices, which will be used to store
+    # lower and upper limits of bootstrap estimates
+    temporal_matrix_lower <- temporal_matrix
+    temporal_matrix_upper <- temporal_matrix
     pb <- txtProgressBar(min = 0, max = (upper_limit - lower_limit),
                          style = 3)
 
@@ -1826,7 +1914,7 @@ for (m in 1:length(empty_list_datasets)){
     width_sequence = seq(lower_limit, upper_limit)
 
     if (is.null(plot_specific_window)){
-      (plot_specificA <- "plot_specific_window is not avaliable. No plot_specific is made!")
+      (plot_specificA <- "plot_specific_window is not available. No plot_specific is made!")
     } else if (fixed_width != 0){
 
       if (fixed_width != plot_specific_window){
@@ -1840,7 +1928,7 @@ for (m in 1:length(empty_list_datasets)){
     } else if (plot_specific_window %in% width_sequence){
       plot_specificA <- plot_specific(final_list, window_width = plot_specific_window, ylimits = ylimits,
                                       reference_window = reference_window)
-    } else (plot_specificA <- "Selected plot_specific_window is not avaliable. No plot_specific is made!")
+    } else (plot_specificA <- "Selected plot_specific_window is not available. No plot_specific is made!")
 
     # Here, for the sake of simplicity, we create final list again
     if (method == "lm" | method == "brnn") {
@@ -1855,7 +1943,9 @@ for (m in 1:length(empty_list_datasets)){
                          plot_specific = plot_specificA,
                          PCA_output = PCA_result,
                          type = "daily",
-                         reference_window = reference_window)
+                         reference_window = reference_window,
+                         boot_lower = temporal_matrix_lower,
+                         boot_upper = temporal_matrix_upper)
     }
 
     if (method == "cor"){
@@ -1871,7 +1961,9 @@ for (m in 1:length(empty_list_datasets)){
                          plot_specific = plot_specificA,
                          PCA_output = PCA_result,
                          type = "daily",
-                         reference_window = reference_window)
+                         reference_window = reference_window,
+                         boot_lower = temporal_matrix_lower,
+                         boot_upper = temporal_matrix_upper)
     }
 
     class(final_list) <- 'dmrs'
