@@ -67,7 +67,7 @@
 #' progressively add 1 split at a time and calculate selected metric. For running window,
 #' select the length of running window with the k_running_window argument.
 #' @param k_running_window the length of running window for temporal stability check.
-#' Applicalbe only if temporal_stability argument is set to running window.
+#' Applicable only if temporal_stability argument is set to running window.
 #' @param k integer, number of breaks (splits) for temporal stability and cross validation
 #' analysis.
 #' @param cross_validation_type character string, specifying, how to perform cross validation
@@ -82,8 +82,16 @@
 #' @param seed optional seed argument for reproducible results
 #' @param tidy_env_data if set to TRUE, env_data should be inserted as a data frame with three
 #' columns: "Year", "Month", "Precipitation/Temperature/etc."
+#' @param boot logical, if TRUE, bootstrap procedure will be used to calculate
+#' estimates correlation coefficients, R squared or adjusted R squared metrices
+#' @param boot_n The number of bootstrap replicates
+#' @param boot_ci_type A character string representing the type of bootstrap intervals
+#' required. The value should be any subset of the values c("norm","basic", "stud",
+#' "perc", "bca").
+#' @param boot_conf_int A scalar or vector containing the confidence level(s) of
+#' the required interval(s)
 #'
-#' @return a list with 15 elements:
+#' @return a list with 17 elements:
 #' \tabular{rll}{
 #'  1 \tab $calculations   \tab a matrix with calculated metrics\cr
 #'  2 \tab $method \tab the character string of a method \cr
@@ -96,10 +104,12 @@
 #'  9\tab $cross_validation   \tab a data frame with cross validation results \cr
 #'  10 \tab $plot_heatmap    \tab ggplot2 object: a heatmap of calculated metrics\cr
 #'  11 \tab $plot_extreme    \tab ggplot2 object: line or bar plot of a row with the highest value in a matrix of calculated metrics\cr
-#'  12 \tab $plot_specific    \tab not avaliable for monthly_response() \cr
+#'  12 \tab $plot_specific    \tab not available for monthly_response() \cr
 #'  13 \tab $PCA_output    \tab princomp object: the result output of the PCA analysis\cr
 #'  14 \tab $type    \tab the character string describing type of analysis: daily or monthly\cr
-#'  15 \tab $reference_window \tab character string, which referece window was used for calculations
+#'  15 \tab $reference_window \tab character string, which reference window was used for calculations\cr
+#'  16 \tab $boot_lower \tab matrix with lower limit of confidence intervals of bootstrap calculations \cr
+#'  17 \tab $boot_upper \tab matrix with upper limit of confidence intervals of bootstrap calculations
 #'}
 #'
 #' @export
@@ -120,10 +130,10 @@
 #'
 #' # 1 Example with tidy precipitation data
 #' example_tidy_data <- monthly_response(response = data_MVA, env_data = LJ_monthly_precipitation,
-#'                                      method = "cor", row_names_subset = TRUE,
+#'                                      method = "lm", row_names_subset = TRUE,
 #'                                      remove_insignificant = TRUE, previous_year = TRUE,
 #'                                      alpha = 0.05, aggregate_function = 'sum',
-#'                                      tidy_env_data = TRUE, previous_year = TRUE)
+#'                                      tidy_env_data = TRUE, boot = FALSE)
 #' summary(example_tidy_data)
 #' example_tidy_data$plot_extreme
 #' example_tidy_data$plot_heatmap
@@ -138,7 +148,7 @@
 #'                                       method = "cor", row_names_subset = TRUE, alpha = 0.05,
 #'                                       previous_year = TRUE, remove_insignificant = TRUE,
 #'                                       subset_years = c(1981, 2010), aggregate_function = 'mean')
-#'
+#' summary(example_MVA_present)
 #' example_MVA_past$plot_heatmap
 #' example_MVA_present$plot_heatmap
 #' example_MVA_past$plot_extreme
@@ -162,6 +172,7 @@
 #'                                     method = "cor", row_names_subset = TRUE,
 #'                                     remove_insignificant = TRUE)
 #'
+#' summary(example_neg_cor)
 #' example_neg_cor$plot_heatmap
 #' example_neg_cor$plot_extreme
 #' example_neg_cor$temporal_stability
@@ -176,6 +187,7 @@
 #'                                      row_names_subset = TRUE, previous_year = FALSE,
 #'                                      remove_insignificant = TRUE, alpha = 0.05)
 #'
+#' summary(example_multiproxy)
 #' example_multiproxy$plot_heatmap
 #'
 #' # 6 Example to test the temporal stability
@@ -184,6 +196,7 @@
 #' remove_insignificant = TRUE, alpha = 0.05,
 #' temporal_stability_check = "running_window", k_running_window = 10)
 #'
+#' summary(example_MVA_ts)
 #' example_MVA_ts$temporal_stability
 #'
 #' }
@@ -200,7 +213,9 @@ monthly_response <- function(response, env_data, method = "lm",
                            temporal_stability_check = "sequential", k = 2,
                            k_running_window = 30, cross_validation_type = "blocked",
                            subset_years = NULL, plot_specific_window = NULL,
-                           ylimits = NULL, seed = NULL, tidy_env_data = FALSE) {
+                           ylimits = NULL, seed = NULL, tidy_env_data = FALSE,
+                           boot = FALSE, boot_n = 1000, boot_ci_type = "norm",
+                           boot_conf_int = 0.95) {
 
 
   if (!is.null(seed)) {
@@ -233,7 +248,17 @@ monthly_response <- function(response, env_data, method = "lm",
  DE <- NULL
  d <- NULL
 
- # If there is a column name samp.depth in response data frame, warning is given
+ temporal_matrix_lower <- NULL
+ temporal_matrix_upper <- NULL
+
+ if (boot == TRUE & method != "cor"){
+
+   warning(paste0("Bootstrapping is currently available only for correlation coefficients!",
+                  "boot argument is ignored!"))
+
+ }
+
+  # If there is a column name samp.depth in response data frame, warning is given
  if ("samp.depth" %in% colnames(response)){
 
    samp.depth_index <- grep("samp.depth", colnames(response))
@@ -355,7 +380,7 @@ monthly_response <- function(response, env_data, method = "lm",
   # If row_names_subset == TRUE, data is subseted and ordered based on matching
   # row.names. Additionally, number of characters in row.names is checked.
   # There should be at least three characters (assuming years before 100 will
-  # never be analysed, there is no such environmental data avaliable)
+  # never be analysed, there is no such environmental data available)
   if (row_names_subset == TRUE & nchar(row.names(env_data)[1]) >= 3){
 
     ncol_response <- ncol(response)
@@ -470,6 +495,11 @@ monthly_response <- function(response, env_data, method = "lm",
                                                    1 + fixed_width/2 ),0))
       }
 
+      # Here I create two additional temporal matrices, which will be used to store
+      # lower and upper limits of bootstrap estimates
+      temporal_matrix_lower <- temporal_matrix
+      temporal_matrix_upper <- temporal_matrix
+
       pb <- txtProgressBar(min = 0, max = (ncol(env_data) - fixed_width + 1),
                            style = 3)
 
@@ -541,6 +571,11 @@ monthly_response <- function(response, env_data, method = "lm",
                                                  1 + fixed_width/2 ),0))
     }
 
+    # Here I create two additional temporal matrices, which will be used to store
+    # lower and upper limits of bootstrap estimates
+    temporal_matrix_lower <- temporal_matrix
+    temporal_matrix_upper <- temporal_matrix
+
     pb <- txtProgressBar(min = 0, max = (ncol(env_data) - fixed_width + 1),
                          style = 3)
 
@@ -615,6 +650,11 @@ monthly_response <- function(response, env_data, method = "lm",
                                                  1 + fixed_width/2 ),0))
     }
 
+    # Here I create two additional temporal matrices, which will be used to store
+    # lower and upper limits of bootstrap estimates
+    temporal_matrix_lower <- temporal_matrix
+    temporal_matrix_upper <- temporal_matrix
+
     pb <- txtProgressBar(min = 0, max = (ncol(env_data) - fixed_width + 1),
                          style = 3)
 
@@ -716,6 +756,12 @@ monthly_response <- function(response, env_data, method = "lm",
                                                  1 + lower_limit/2 ),0))
     }
 
+    # Here I create two additional temporal matrices, which will be used to store
+    # lower and upper limits of bootstrap estimates
+    temporal_matrix_lower <- temporal_matrix
+    temporal_matrix_upper <- temporal_matrix
+
+
   # An iterating double loop: 1 outer loop) iterating from lower_limit :
   # upper_limit defines windo.width used for a moving window. 2) inner loop
   # defines the starting position of a moving window.
@@ -763,18 +809,40 @@ monthly_response <- function(response, env_data, method = "lm",
       }
 
       x <- matrix(x, nrow = nrow(env_data), ncol = 1)
-      temporal_correlation <- cor(response[, 1], x[, 1], method = cor_method)
+
+
+      if (boot == FALSE){
+        temporal_correlation <- cor(response[, 1], x[, 1], method = cor_method)
+        temporal_lower <- NA
+        temporal_upper <- NA
+      } else if (boot == TRUE){
+        temp_df_boot <- cbind(response[, 1], x[, 1])
+        calc <- boot(temp_df_boot, boot_f, fun = "cor", cor.type = cor_method, R = boot_n)
+
+        temporal_correlation <- colMeans(calc$t)[1]
+
+        ci_int <- boot.ci(calc, conf = boot_conf_int, type = boot_ci_type)
+        temporal_lower <- ci_int$norm[2]
+        temporal_upper <- ci_int$norm[3]
+      } else {
+        print(paste0("boot should be TRUE or FALSE, instead it is ", boot))
+      }
 
       if (reference_window == 'start'){
         temporal_matrix[(K - lower_limit) + 1, j + 1] <- temporal_correlation
+        temporal_matrix_lower[(K - lower_limit) + 1, j + 1] <- temporal_lower
+        temporal_matrix_upper[(K - lower_limit) + 1, j + 1] <- temporal_upper
       } else if (reference_window == 'end'){
         temporal_matrix[(K - lower_limit) + 1, j + K] <- temporal_correlation
+        temporal_matrix_lower[(K - lower_limit) + 1, j + K] <- temporal_lower
+        temporal_matrix_upper[(K - lower_limit) + 1, j + K] <- temporal_upper
       } else if (reference_window == 'middle'){
         temporal_matrix[(K - lower_limit) + 1, round2(j + 1 + K/2, 0)] <- temporal_correlation
+        temporal_matrix_lower[(K - lower_limit) + 1, round2(j + 1 + K/2, 0)] <- temporal_lower
+        temporal_matrix_upper[(K - lower_limit) + 1, round2(j + 1 + K/2, 0)] <- temporal_upper
       }
 
-
-      }
+        }
     setTxtProgressBar(pb, b)
   }
 
@@ -784,12 +852,17 @@ monthly_response <- function(response, env_data, method = "lm",
   # window width used fot calculations. Colnames represent the position of
   # moving window in a original env_data data frame.
   temporal_rownames <- as.vector(seq(from = lower_limit, to = upper_limit,
-    by = 1))
+                                     by = 1))
   row.names(temporal_matrix) <- temporal_rownames
+  row.names(temporal_matrix_lower) <- temporal_rownames
+  row.names(temporal_matrix_upper) <- temporal_rownames
+
 
   temporal_colnames <- as.vector(seq(from = 1,
-    to = ncol(temporal_matrix), by = 1))
+                                     to = ncol(temporal_matrix), by = 1))
   colnames(temporal_matrix) <- temporal_colnames
+  colnames(temporal_matrix_lower) <- temporal_colnames
+  colnames(temporal_matrix_upper) <- temporal_colnames
   }
 
   # B.2 method == "lm"
@@ -808,6 +881,10 @@ monthly_response <- function(response, env_data, method = "lm",
                                                  1 + lower_limit/2 ),0))
     }
 
+    # Here I create two additional temporal matrices, which will be used to store
+    # lower and upper limits of bootstrap estimates
+    temporal_matrix_lower <- temporal_matrix
+    temporal_matrix_upper <- temporal_matrix
 
     pb <- txtProgressBar(min = 0, max = (upper_limit - lower_limit),
                          style = 3)
@@ -903,6 +980,11 @@ monthly_response <- function(response, env_data, method = "lm",
                                                  1 + lower_limit/2 ),0))
     }
 
+    # Here I create two additional temporal matrices, which will be used to store
+    # lower and upper limits of bootstrap estimates
+    temporal_matrix_lower <- temporal_matrix
+    temporal_matrix_upper <- temporal_matrix
+
     pb <- txtProgressBar(min = 0, max = (upper_limit - lower_limit),
                          style = 3)
 
@@ -1844,7 +1926,7 @@ for (m in 1:length(empty_list_datasets)){
     width_sequence = seq(lower_limit, upper_limit)
 
     if (is.null(plot_specific_window)){
-      (plot_specificA <- "plot_specific_window is not avaliable for monthly_response function!")
+      (plot_specificA <- "plot_specific_window is not available for monthly_response function!")
     } else if (fixed_width != 0){
 
       if (fixed_width != plot_specific_window){
@@ -1858,7 +1940,7 @@ for (m in 1:length(empty_list_datasets)){
     } else if (plot_specific_window %in% width_sequence){
       plot_specificA <- plot_specific(final_list, window_width = plot_specific_window, ylimits = ylimits,
                                       reference_window = reference_window, type = "monthly")
-    } else (plot_specificA <- "Selected plot_specific_window is not avaliable. No plot_specific is made!")
+    } else (plot_specificA <- "Selected plot_specific_window is not available. No plot_specific is made!")
 
     # Here, for the sake of simplicity, we create final list again
     if (method == "lm" | method == "brnn") {
@@ -1873,7 +1955,9 @@ for (m in 1:length(empty_list_datasets)){
                          plot_specific = plot_specificA,
                          PCA_output = PCA_result,
                          type = "monthly",
-                         reference_window = reference_window)
+                         reference_window = reference_window,
+                         boot_lower = temporal_matrix_lower,
+                         boot_upper = temporal_matrix_upper)
     }
 
     if (method == "cor"){
@@ -1888,7 +1972,9 @@ for (m in 1:length(empty_list_datasets)){
                          plot_specific = plot_specificA,
                          PCA_output = PCA_result,
                          type = "monthly",
-                         reference_window = reference_window)
+                         reference_window = reference_window,
+                         boot_lower = temporal_matrix_lower,
+                         boot_upper = temporal_matrix_upper)
     }
 
     class(final_list) <- 'dmrs'
